@@ -419,13 +419,15 @@ from drf_yasg.renderers import SwaggerUIRenderer, OpenAPIRenderer""" in line:
 
         # Check if view already exists
         if not self.view_exists(view_path, "%s_list" % lower_model):
-            view_list.append(LIST_VIEW % {'lower_model': lower_model, 'model': self.model, 'app': self.app})
+            view_list.append(LIST_VIEW % {'lower_model': lower_model, 'model': self.model})
             self._info("added \t%s\t%s_view" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_view" % (view_path, lower_model), 1)
 
+
+
         if not self.view_exists(view_path, "%s_details" % lower_model):
-            view_list.append(DETAILS_VIEW % {'lower_model': lower_model, 'model': self.model, 'app': self.app})
+            view_list.append(DETAILS_VIEW % {'lower_model': lower_model, 'model': self.model})
             self._info("added \t%s\t%s_details" % (view_path, lower_model), 1)
         else:
             self._info("exists\t%s\t%s_details" % (view_path, lower_model), 1)
